==> urubu-1.0.0.tar.gz: urubu-1.0.0/doc/index.md <==
---
title: Urubu 
layout: home
content:
    - start 
    - manual 
    - ref: urubu-quickstart
      title: Quickstart
    - faq
    - more 
tagline:
    A micro CMS for static websites, with a focus on good
    navigation practices.
---
<div class="row">

    <div class="col-md-4">
<h4>For websites, not just blogs</h4>
<p>
Set up a website as logically related content. Content
ordering is flexible, not just by date.
</p>  
    </div>

    <div class="col-md-4">
<h4>Focus on navigation</h4>
<p>
Easily set up a navbar, a table of contents sidebar,
breadcrumbs and pagers. 
</p>
    </div>

    <div class="col-md-4">
<h4>Ready for Bootstrap</h4>
<p>
Urubu plays well with Bootstrap, the popular framework
for great looking websites.
</p>
    </div>

<div class="clearfix visible-md visible-lg"></div>

    <div class="col-md-4">
<h4>Markdown content</h4>
<p>
Enter content in light-weight Markdown syntax, with
popular extensions.
</p>
    </div>

    <div class="col-md-4">
<h4>Wiki links</h4>
<p>
Easily refer to other pages like
in wikis, using Markdown syntax. 
</p>
    </div> 

    <div class="col-md-4">
<h4>Powerful templating</h4>
<p>
Use the powerful Jinja2 templating library to 
define page layouts.
</p>  
    </div>

<div class="clearfix visible-md visible-lg"></div>

    <div class="col-md-4">
<h4>Sophisticated control</h4>
<p>
  Per-page control of page layout 
  and other stuff. Plus
  user-defined variables.  
</p>  
    </div>

    <div class="col-md-4">
<h4>Python power</h4>
<p>
Urubu is built with Python. It provides Python hooks
to assist in templating.   
</p>  
    </div>

    <div class="col-md-4">
<h4>Ideal with git or mercurial</h4>
<p>
Use a git or mercurial workflow to develop
your website. Deploy by pushing.
</p>
    </div>

</div>

<hr class="half-rule">


<div class="row">
  <div class="col-md-8 col-md-offset-2 text-center">
    <p class="lead">And of course, it's open source!</p>  
  </div>
</div>

==> urubu-1.3.1.tar.gz: urubu-1.3.1/doc/index.md <==
---
title: Urubu 
layout: home
content:
    - start 
    - manual 
    - ref: urubu-quickstart
      title: Quickstart
    - faq
    - more 
tagline:
    A micro CMS for static websites
---
<div class="row">

    <div class="col-md-4">
<h4>For websites, <mark>not just blogs</mark></h4>
<p>
Set up a website as logically related content. <mark>Content
ordering is flexible</mark>, not just by date.
</p>  
    </div>

    <div class="col-md-4">
<h4>Focus on <mark>navigation</mark></h4>
<p>
Easily set up a navbar, a table of contents sidebar,
breadcrumbs and pagers. 
</p>
    </div>

    <div class="col-md-4">
<h4>Ready for Bootstrap</h4>
<p>
Urubu plays well with <mark>Bootstrap</mark>, the popular framework
for great looking websites.
</p>
    </div>

<div class="clearfix visible-md visible-lg"></div>

    <div class="col-md-4">
<h4>Markdown content</h4>
<p>
Enter content in light-weight <mark>Markdown</mark> syntax, with
popular extensions.
</p>
    </div>

    <div class="col-md-4">
<h4>Wiki links</h4>
<p>
<mark>Easily refer to other pages like
in wikis</mark>, using Markdown syntax. 
</p>
    </div> 

    <div class="col-md-4">
<h4>Powerful templating</h4>
<p>
Use the powerful <mark>Jinja2 templating</mark> library to 
define page layouts.
</p>  
    </div>

<div class="clearfix visible-md visible-lg"></div>

    <div class="col-md-4">
<h4>Sophisticated control</h4>
<p>
  Per-page control of page layout 
  and other stuff. Plus
  <mark>user-defined variables</mark>.  
</p>  
    </div>

    <div class="col-md-4">
<h4>Python power</h4>
<p>
Urubu is built with Python. It provides <mark>Python hooks</mark>
to assist in templating.   
</p>  
    </div>

    <div class="col-md-4">
<h4>Ideal with git</h4>
<p>
Use a <mark>git workflow</mark> to develop
your website. Deploy by pushing.
</p>
    </div>

</div>

<hr class="half-rule">


<div class="row">
  <div class="col-md-8 col-md-offset-2 text-center">
    <p class="lead">And of course, it's open source!</p>  
  </div>
</div>
